EventBus

Struct EventBus 

pub struct EventBus { /* private fields */ }
Thread-safe event bus for runtime events

The event bus allows subscribers to register listeners that will be called when events are emitted. All listener calls are synchronous and blocking. Uses lock-free arc-swap for optimal performance when emitting frequent events.

Implementations

Source

impl EventBus

pub fn new() -> Self

Create a new event bus

pub fn subscribe<F>(&self, listener: F) -> ListenerId
where F: Fn(&Event) + Send + Sync + 'static,

Register an event listener

Returns a listener ID that can be used to unsubscribe (future enhancement). The listener will be called for all events emitted on this bus. Uses read-copy-update (RCU) for lock-free hot-reload.

pub fn emit(&self, event: &Event)

Emit an event to all listeners

Listeners are called synchronously in the order they were registered. If a listener panics, the panic is caught and other listeners continue. Lock-free load for optimal performance on frequent emissions.

pub fn log(&self, level: LogLevel, target: &str, message: String)

Emit a log event

pub fn progress(&self, data: ProgressState)

Emit a progress event

pub fn step(&self, message: String)

Emit a step event

pub fn warn(&self, message: String)

Emit a warning event

pub fn error(&self, message: String)

Emit an error event

Source

impl EventBus

pub fn create_log_adapter(&self) -> LogAdapter

Create a log adapter that forwards log crate events to the event bus