pub struct ContainerRegistry { /* private fields */ }Expand description
Re‑exports reader/writer traits, converters, and auxiliary types. Registry mapping file extensions to async tile container readers and writers.
Supports reading and writing of tile containers in formats such as:
MBTiles- TAR
PMTilesVersaTiles- Directory-based containers
Implementations
Sourceimpl ContainerRegistry
impl ContainerRegistry
Sourcepub fn new_empty() -> Self
pub fn new_empty() -> Self
Creates a new ContainerRegistry with the specified runtime.
Registers built-in readers and writers for supported container formats.
pub async fn reader_from_str( &self, data_source: &str, runtime: TilesRuntime, ) -> Result<SharedTileSource>
Sourcepub async fn reader_from_location(
&self,
location: DataLocation,
runtime: TilesRuntime,
) -> Result<SharedTileSource>
pub async fn reader_from_location( &self, location: DataLocation, runtime: TilesRuntime, ) -> Result<SharedTileSource>
Get a tile container reader for a given DataLocation (path or URL).
Sourcepub async fn reader(
&self,
data_source: DataSource,
runtime: TilesRuntime,
) -> Result<SharedTileSource>
pub async fn reader( &self, data_source: DataSource, runtime: TilesRuntime, ) -> Result<SharedTileSource>
Sourcepub async fn write_to_path(
&self,
reader: SharedTileSource,
path: &Path,
runtime: TilesRuntime,
) -> Result<()>
pub async fn write_to_path( &self, reader: SharedTileSource, path: &Path, runtime: TilesRuntime, ) -> Result<()>
Write tiles with a custom runtime for progress monitoring and other options.
Arguments
reader- A shared tile source providing tiles to write.path- The output path to write tiles to.runtime- Runtime configuration (cache type, event bus, progress factory, etc.).
Returns
Result indicating success or failure.
Sourcepub async fn write_to_str(
&self,
reader: SharedTileSource,
destination: &str,
runtime: TilesRuntime,
) -> Result<()>
pub async fn write_to_str( &self, reader: SharedTileSource, destination: &str, runtime: TilesRuntime, ) -> Result<()>
Write tiles to a destination specified as a string (path or SFTP URL).
Detects sftp:// URLs and writes via SFTP when the ssh2 feature is enabled.
Otherwise falls back to path-based writing.
Sourcepub fn register_reader<R: TilesReader + 'static>(&mut self, ext: &str)
pub fn register_reader<R: TilesReader + 'static>(&mut self, ext: &str)
Register both file and (optionally) data readers for a TilesReader implementation.
The file reader is always registered. The data reader is only registered when
R::supports_data_reader() returns true.
Sourcepub fn register_writer<W: TilesWriter + 'static>(&mut self, ext: &str)
pub fn register_writer<W: TilesWriter + 'static>(&mut self, ext: &str)
Register both file and (optionally) data writers for a TilesWriter implementation.
The file writer is always registered. The data writer is only registered when
W::supports_data_writer() returns true.
pub fn supports_reader_extension(&self, ext: &str) -> bool
pub fn supports_writer_extension(&self, ext: &str) -> bool