pub struct EventBus { /* private fields */ }Expand description
Thread-safe event bus for runtime events
The event bus allows subscribers to register listeners that will be called when events are emitted. All listener calls are synchronous and blocking. Uses lock-free arc-swap for optimal performance when emitting frequent events.
Implementations
Sourceimpl EventBus
impl EventBus
Sourcepub fn subscribe<F>(&self, listener: F) -> ListenerId
pub fn subscribe<F>(&self, listener: F) -> ListenerId
Register an event listener
Returns a listener ID that can be used to unsubscribe (future enhancement). The listener will be called for all events emitted on this bus. Uses read-copy-update (RCU) for lock-free hot-reload.
Sourcepub fn emit(&self, event: &Event)
pub fn emit(&self, event: &Event)
Emit an event to all listeners
Listeners are called synchronously in the order they were registered. If a listener panics, the panic is caught and other listeners continue. Lock-free load for optimal performance on frequent emissions.
Sourcepub fn progress(&self, data: ProgressState)
pub fn progress(&self, data: ProgressState)
Emit a progress event
Sourceimpl EventBus
impl EventBus
Sourcepub fn create_log_adapter(&self) -> LogAdapter
pub fn create_log_adapter(&self) -> LogAdapter
Create a log adapter that forwards log crate events to the event bus